==> frontengine_dev-0.0.21.tar.gz: frontengine_dev-0.0.21/frontengine/utils/multi_language/traditional_chinese.py <==
traditional_chinese_word_dict = {
    # Menubar
    "menu_bar_language": "選擇語言",
    "menu_bar_ui_style": "選擇介面風格",
    # Language Menubar
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁體中文",
    "language_menu_bar_please_restart_messagebox": "請重啟以應用更改",
    # Tab text
    "tab_video_text": "影片",
    "tab_image_text": "圖片",
    "tab_web_text": "網頁",
    "tab_gif_text": "GIF 和 WEBP",
    "tab_sound_text": "音樂",
    "tab_text_text": "文字",
    "tab_external_ui": "外部 UI",
    "tab_control_center_text": "控制中心",
    "chat_ui_text": "聊天",
    # Messagebox text
    "paint_gif_message_text": "GIF 或者 WEBP 檔案有錯誤",
    "paint_image_message_box_text": "圖片錯誤",
    "sound_effect_message_box_text": "音樂錯誤",
    "sound_player_message_box_text": "音樂錯誤",
    "video_player_message_box_text": "影片錯誤",
    "webview_message_box_text": "網頁錯誤",
    "cant_find_extend_ui_message_box_text": "未找到 UI",
    # Control Center UI
    "control_center_close_all_video": "關閉全部影片",
    "control_center_close_all_image": "關閉全部圖片",
    "control_center_close_all_gif": "關閉全部 GIF",
    "control_center_close_all_web": "關閉全部網頁",
    "control_center_close_all_sound": "關閉全部音樂",
    "control_center_close_all_text": "關閉全部文字",
    "control_center_scene": "關閉場景",
    "control_center_clear_log_panel": "清除 Log",
    "chat_scene_close": "關閉所有聊天",
    "control_center_close_all": "關閉所有",
    # General
    "Opacity": "不透明度",
    "Speed": "速度",
    "Not Ready": "未準備好",
    "Ready": "已準備好",
    "Show on all screen": "顯示在所有螢幕",
    "Volume": "音量",
    "Font size": "字體大小",
    "Play rate": "撥放速度",
    "not_prepare": "尚未準備好",
    "Show on bottom": "顯示在所有視窗底部",
    "url": "連結",
    "text": "文字",
    "ui_path": "UI 路徑",
    "position_x": "X 座標",
    "position_y": "Y 座標",
    # GIF setting ui
    "gif_setting_ui_choose_file": "選擇 GIF 或 WEBP 檔案",
    "gif_setting_ui_play": "開始撥放 GIF 或 WEBP",
    "gif_setting_message_box": "請選擇 GIF 或 WEBP 檔案",
    # Image setting ui
    "image_setting_choose_file": "選擇圖片",
    "image_setting_ui_play": "開始撥放圖片",
    "image_setting_message_box": "請選擇圖片",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "選擇 wav 檔案",
    "sound_player_setting_choose_sound_file": "請選擇音檔",
    "sound_player_setting_play_wav": "開始撥放 wav",
    "sound_player_setting_play_sound": "開始撥放音檔",
    "sound_player_setting_message_box_wav": "請選擇 wav 檔案",
    "sound_player_setting_message_box_sound": "請選擇音檔",
    # Text setting ui
    "text_setting_start_draw": "開始在螢幕上繪製文字",
    # Video setting ui
    "video_setting_choose_file": "選擇影片檔案",
    "video_setting_start_play": "開始撥放影片",
    "video_setting_message_box": "請選擇影片檔案",
    # Web setting ui
    "web_setting_open_url": "用網址開啟網頁",
    "web_setting_open_local_file": "開啟本地網頁",
    "web_setting_open_enable_input": "啟用輸入",
    # Scene UI
    "tab_scene_text": "場景",
    "scene_table_view_type": "類型",
    "scene_file_path": "檔案路徑",
    "scene_setting_start_scene_button": "開始場景",
    "scene_add_image": "添加圖片到場景",
    "scene_add_gif": "添加動圖到場景",
    "scene_add_sound": "添加聲音到場景",
    "scene_add_text": "添加文字到場景",
    "scene_add_video": "添加影片到場景",
    "scene_add_web": "添加網頁到場景",
    "scene_add_UI": "添加UI到場景",
    "scene_choose_message_box": "請選擇場景檔案",
    "scene_choose_output_path_message_box": "請選擇場景檔案輸出路徑",
    "scene_output": "輸出場景檔案",
    "scene_input": "讀取場景檔案",
    "tableview_clear": "清除所有設定",
    "scene_control_panel": "場景控制中心",
    # Chat scene input
    "chat_scene_input_title": "輸入聊天內容",
    "chat_scene_send_chat": "送出文字",
    # Chat scene
    "chat_scene_start_button": "開始聊天",
    "chat_scene_new_topic": "開始一個新聊天",
    "chat_scene_creative": "創意",
    "chat_scene_precise": "精準",
    "chat_scene_balanced": "平衡",
}

==> frontengine_dev-0.0.76.tar.gz: frontengine_dev-0.0.76/frontengine/utils/multi_language/traditional_chinese.py <==
traditional_chinese_word_dict = {
    # Menubar
    "menu_bar_language": "選擇語言",
    "menu_bar_ui_style": "選擇介面風格",
    # Language Menubar
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁體中文",
    "language_menu_bar_simplified_chinese": "簡體中文",
    "language_menu_bar_germany": "德文",
    "language_menu_bar_russian": "俄羅斯文",
    "language_menu_bar_french": "法文",
    "language_menu_bar_italian": "義大利文",
    "language_menu_bar_please_restart_messagebox": "請重啟以應用更改",
    # Tab text
    "tab_video_text": "影片",
    "tab_image_text": "圖片",
    "tab_web_text": "網頁",
    "tab_gif_text": "GIF 和 WEBP",
    "tab_sound_text": "音樂",
    "tab_text_text": "文字",
    "tab_external_ui": "外部 UI",
    "tab_control_center_text": "控制中心",
    "chat_ui_text": "聊天",
    # Messagebox text
    "paint_gif_message_text": "GIF 或者 WEBP 檔案有錯誤",
    "paint_image_message_box_text": "圖片錯誤",
    "sound_effect_message_box_text": "音樂錯誤",
    "sound_player_message_box_text": "音樂錯誤",
    "video_player_message_box_text": "影片錯誤",
    "webview_message_box_text": "網頁錯誤",
    "cant_find_extend_ui_message_box_text": "未找到 UI",
    # Control Center UI
    "control_center_close_all_video": "關閉全部影片",
    "control_center_close_all_image": "關閉全部圖片",
    "control_center_close_all_gif": "關閉全部 GIF",
    "control_center_close_all_web": "關閉全部網頁",
    "control_center_close_all_sound": "關閉全部音樂",
    "control_center_close_all_text": "關閉全部文字",
    "control_center_scene": "關閉場景",
    "control_center_clear_log_panel": "清除 Log",
    "chat_scene_close": "關閉所有聊天",
    "control_center_close_all": "關閉所有",
    # General
    "Opacity": "不透明度",
    "Speed": "速度",
    "Not Ready": "未準備好",
    "Ready": "已準備好",
    "Show on all screen": "顯示在所有螢幕",
    "Volume": "音量",
    "Font size": "字體大小",
    "Play rate": "撥放速度",
    "not_prepare": "尚未準備好",
    "Show on bottom": "顯示在所有視窗底部",
    "url": "連結",
    "text": "文字",
    "ui_path": "UI 路徑",
    "position_x": "X 座標",
    "position_y": "Y 座標",
    "seconds": "秒",
    "close_delay": "字幕消失時間 秒",
    "country_code": "區域代碼",
    "show_on_which_monitor": "顯示在哪個螢幕",
    "ok": "確定",
    "no": "否",
    "fullscreen_checkbox_label": "全螢幕?",
    # GIF setting ui
    "gif_setting_ui_choose_file": "選擇 GIF 或 WEBP 檔案",
    "gif_setting_ui_play": "開始撥放 GIF 或 WEBP",
    "gif_setting_message_box": "請選擇 GIF 或 WEBP 檔案",
    # Image setting ui
    "image_setting_choose_file": "選擇圖片",
    "image_setting_ui_play": "開始撥放圖片",
    "image_setting_message_box": "請選擇圖片",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "選擇 wav 檔案",
    "sound_player_setting_choose_sound_file": "請選擇音檔",
    "sound_player_setting_play_wav": "開始撥放 wav",
    "sound_player_setting_play_sound": "開始撥放音檔",
    "sound_player_setting_message_box_wav": "請選擇 wav 檔案",
    "sound_player_setting_message_box_sound": "請選擇音檔",
    # Text setting ui
    "text_setting_start_draw": "開始在螢幕上繪製文字",
    "text_setting_choose_alignment": "選擇文字排列方式",
    "text_setting_alignment_Top": "置頂",
    # Video setting ui
    "video_setting_choose_file": "選擇影片檔案",
    "video_setting_start_play": "開始撥放影片",
    "video_setting_message_box": "請選擇影片檔案",
    # Web setting ui
    "web_setting_open_url": "用網址開啟網頁",
    "web_setting_open_local_file": "開啟本地網頁",
    "web_setting_open_enable_input": "啟用輸入",
    # Scene UI
    "tab_scene_text": "場景",
    "scene_start": "開始場景",
    "scene_table_view_type": "類型",
    "scene_file_path": "檔案路徑",
    "scene_setting_start_scene_button": "開始場景",
    "scene_add_image": "添加圖片到場景",
    "scene_add_gif": "添加動圖到場景",
    "scene_add_sound": "添加聲音到場景",
    "scene_add_text": "添加文字到場景",
    "scene_add_video": "添加影片到場景",
    "scene_add_web": "添加網頁到場景",
    "scene_url_label": "網址",
    "scene_add_UI": "添加UI到場景",
    "scene_choose_message_box": "請選擇場景檔案",
    "scene_choose_output_path_message_box": "請選擇場景檔案輸出路徑",
    "scene_output": "輸出場景檔案",
    "scene_input": "讀取場景檔案",
    "scene_script_clear": "清除所有腳本",
    "scene_script": "場景腳本",
    # Particle ui
    "tab_particle_text": "粒子",
    "choose_particle_direction": "選擇粒子方向",
    "particle_setting_ui_play": "開始播放粒子",
    "particle_size": "粒子大小",
    "particle_count": "粒子數量",
    "particle_speed": "粒子速度",
    # Chat scene input
    "chat_scene_input_title": "輸入聊天內容",
    "chat_scene_send_chat": "送出文字",
    # Chat scene
    "chat_scene_start_button": "開始聊天",
    "chat_scene_new_topic": "開始一個新話題",
    "chat_scene_creative": "創意",
    "chat_scene_precise": "精準",
    "chat_scene_balanced": "平衡",
    "chat_gpt_exception": "GPT 錯誤，請重試或開始一個新話題",
    "should_we_show_toast": "顯示對話?",
    # Chat voice input
    "start_chat_voice_input_ui": "開啟聲音輸入介面",
    "chat_recognizer_voice_button": "開始錄製聲音",
    # Image Generation
    "image_generation_tab": "圖片產生",
    "start_generate_image": "開始產生圖片",
    "input_error": "請勿無輸入或空格",
    "save_generation_image": "儲存圖片",
    # Help Menu
    "help_menu_label": "幫助選單",
    "help_menu_open_issue": "開啟問題回報",
    "how_to_critical_exit_action": "怎麼強制關閉",
    "how_to_critical_exit": "按下 F12 可以緊急關閉",
    # HowTo Menu
    "doc_menu_label": "文件選單",
    "doc_menu_open_doc": "開啟文件",
}
